Method: YUICompressor.command_arguments

Defined in:
lib/yuicompressor/jruby.rb,
lib/yuicompressor/shell.rb

.command_arguments(options = {}) ⇒ Object

Returns an array of flags that should be passed to the jar file on the command line for the given set of options.



33
34
35
36
37
38
39
40
41
42
43
44
# File 'lib/yuicompressor/jruby.rb', line 33

def command_arguments(options={})
  args = [ options[:line_break] ? options[:line_break].to_i : -1 ]

  if options[:type].to_s == 'js'
    args << !! options[:munge]
    args << false # verbose?
    args << !! options[:preserve_semicolons]
    args << ! options[:optimize] # disable optimizations?
  end

  args
end