Method: YUICompressor.compress_css
- Defined in:
- lib/yuicompressor.rb
.compress_css(stream_or_string, options = {}, &block) ⇒ Object
Compress the given CSS stream_or_string using the given options. Options should be a Hash with any of the following keys:
:line_break-
The maximum number of characters that may appear in a single line of compressed code. Defaults to no maximum length. If set to 0 each line will be the minimum length possible.
:charset-
Charset. Default is utf8.
22 23 24 |
# File 'lib/yuicompressor.rb', line 22 def compress_css(stream_or_string, ={}, &block) compress(stream_or_string, .merge(:type => 'css'), &block) end |